Learn R Programming

minimalRSD (version 1.0.0)

fact.pts: Generate Factorial Points

Description

For a given number of factors, say k, it generates 2^k factorial points such that the number of changes in the run sequence is minimum.

Usage

fact.pts(k)

Arguments

k
an integer greater than or equal to 2.

Value

For K number of factors, generate factorial points with minimum level changes.

Examples

Run this code
# For generating a full factorial for k=4 factors
# in 2 levels with minimum level changes
fact.pts(4)

Run the code above in your browser using DataLab