Learn R Programming

minimalRSD (version 1.0.0)

fact.pts_2: Generate Half Replicate of Full Factorial Points.

Description

For a given number of factors, say k, it generates 2^(k-1) factorial points such that the number of changes in levels in the half replicate is minimum.

Usage

fact.pts_2(k)

Arguments

k
an integer greter than or equal to 3.

Value

For K number of factors, generate factorial points in half replication with minimum level changes.

Examples

Run this code
# For generating a minimally changed half
# replicate of full factorial with 4 factors
# in 2 levels fact.pts_2(4)

Run the code above in your browser using DataLab