Learn R Programming

minimalRSD (version 1.0.0)

min_ccd: Minimally Changed CCD

Description

Generate minimally changed run sequence for central composite designs (CCD).

Usage

min_ccd(k)

Arguments

k
an integer greater than or equal to 2.

Value

returns a minimally changed CCD for K number of factors with full factorial points.

Examples

Run this code
# Generate minimally changed CCD with full factorial points
# for k=4 factors
min_ccd(4)

Run the code above in your browser using DataLab