fact.pts_2: Generate Half Replicate of Full Factorial Points.
Description
For a given number of factors, say k, it generates 2^(k-1) factorial
points such that the number of changes in levels in the half
replicate is minimum.
Usage
fact.pts_2(k)
Arguments
k
an integer greter than or equal to 3.
Value
For K number of factors, generate
factorial points in half replication with minimum level changes.